@@ -13,7 +13,10 @@ use crate::{
 };
 use ruc::*;
 use serde::{Deserialize, Serialize};
-use std::ops::{Deref, DerefMut};
+use std::{
+    collections::BTreeSet,
+    ops::{Deref, DerefMut},
+};
 
 #[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
 pub struct MapxRawMkVs {
@@ -484,6 +487,23 @@ impl VsMgmt for MapxRawMkVs {
         }
     }
 
+    /// Clean up all other branches not in the list.
+    #[inline(always)]
+    fn branch_keep_only(&self, branch_names: &[BranchName]) -> Result<()> {
+        let br_ids = branch_names
+            .iter()
+            .copied()
+            .map(|brname| {
+                self.inner
+                    .branch_get_id_by_name(brname)
+                    .c(d!("version not found"))
+            })
+            .collect::<Result<BTreeSet<_>>>()?
+            .into_iter()
+            .collect::<Vec<_>>();
+        self.inner.branch_keep_only(&br_ids).c(d!())
+    }
+
     #[inline(always)]
     fn branch_truncate(&self, branch_name: BranchName) -> Result<()> {
         self.inner
